@@ -1,5 +1,5 @@
 import { camelCase, lowerCase, lowerFirst, startCase, upperFirst } from 'lodash';
-import { AggregateError, Op } from 'sequelize';
+import { Op } from 'sequelize';
 import { ValidationError as YupValidationError } from 'yup';
 import config from 'config';
 
@@ -7,7 +7,7 @@ import { ForeignkeyResolutionError, UpsertionError, ValidationError } from '../e
 import { statkey, updateStat } from '../stats';
 import * as schemas from '../importSchemas';
 import { validateTableRows } from './validateTableRows';
-import { generateTranslationsForData } from './translationHandler';
+import { generateTranslationsForData, bulkUpsertTranslationDefaults } from './translationHandler';
 
 function findFieldName(values, fkField) {
   const fkFieldLower = fkField.toLowerCase();
@@ -43,6 +43,19 @@ const existingRecordLoaders = {
     TTD.findOne({ where: { taskTemplateId, designationId }, paranoid: false }),
   UserDesignation: (UD, { userId, designationId }) =>
     UD.findOne({ where: { userId, designationId }, paranoid: false }),
+  ProcedureTypeSurvey: async (Model, values) => {
+    const { procedureTypeId, surveyId } = values;
+    if (!procedureTypeId || !surveyId) {
+      return null;
+    }
+    return await Model.findOne({
+      where: {
+        procedureTypeId,
+        surveyId,
+      },
+      paranoid: false,
+    });
+  },
 };
 
 function loadExisting(Model, values) {
@@ -226,6 +239,7 @@ export async function importRows(
   await validateTableRows(models, validRows, pushErrorFn);
 
   log.debug('Upserting database rows', { rows: validRows.length });
+  const translationData = [];
   for (const { model, sheetRow, values } of validRows) {
     const Model = models[model];
     const existing = await loadExisting(Model, values);
@@ -246,7 +260,14 @@ export async function importRows(
 
       if (existing) {
         if (normalizedValues.deletedAt) {
-          if (!['Permission', 'SurveyScreenComponent', 'UserFacility'].includes(model)) {
+          if (
+            ![
+              'Permission',
+              'SurveyScreenComponent',
+              'UserFacility',
+              'ProcedureTypeSurvey',
+            ].includes(model)
+          ) {
             throw new ValidationError(`Deleting ${model} via the importer is not supported`);
           }
           if (!existing.deletedAt) {
@@ -282,29 +303,18 @@ export async function importRows(
         await Model.create(normalizedValues);
         updateStat(stats, statkey(model, sheetName), 'created');
       }
-
       const recordTranslationData = generateTranslationsForData(model, sheetName, normalizedValues);
-      try {
-        await models.TranslatedString.bulkCreate(recordTranslationData, {
-          validate: true,
-          updateOnDuplicate: ['text'],
-        });
-      } catch (err) {
-        if (!(err instanceof AggregateError)) {
-          throw err; // Not a sequelize bulk create error, so let it bubble up
-        }
-
-        updateStat(stats, statkey(model, sheetName), 'errored');
-        for (const error of err.errors) {
-          errors.push(new ValidationError(sheetName, sheetRow, error.message));
-        }
-      }
+      translationData.push(...recordTranslationData);
     } catch (err) {
       updateStat(stats, statkey(model, sheetName), 'errored');
       errors.push(new UpsertionError(sheetName, sheetRow, err));
     }
   }
 
+  if (errors.length === 0) {
+    await bulkUpsertTranslationDefaults(models, translationData);
+  }
+
   log.debug('Done with these rows');
   return stats;
 }
